@@ -1,8 +1,8 @@
 #' Fit a Principal Curve
 #'
-#' Fits a principal curve which describes a smooth curve that passes through the \code{middle}
-#' of the data \code{x} in an orthogonal sense.  This curve is a nonparametric generalization
-#' of a linear principal component.  If a closed curve is fit (using \code{smoother = "periodic_lowess"})
+#' Fit a principal curve which describes a smooth curve that passes through the \code{middle}
+#' of the data \code{x} in an orthogonal sense. This curve is a non-parametric generalization
+#' of a linear principal component. If a closed curve is fit (using \code{smoother = "periodic_lowess"})
 #' then the starting curve defaults to a circle, and each fit is followed by a bias correction
 #' suggested by Jeff Banfield.
 #'
@@ -67,12 +67,11 @@
 #' @examples
 #' x <- runif(100,-1,1)
 #' x <- cbind(x, x ^ 2 + rnorm(100, sd = 0.1))
-#' fit1 <- principal_curve(x, plot_iterations = TRUE)
-#' fit2 <- principal_curve(x, plot_iterations = TRUE, smoother = "lowess")
-#' lines(fit1)
-#' points(fit1)
-#' plot(fit1)
-#' whiskers(x, fit1$s)
+#' fit <- principal_curve(x)
+#' plot(fit)
+#' lines(fit)
+#' points(fit)
+#' whiskers(x, fit$s)
 principal_curve <- function(
   x,
   start = NULL,
@@ -178,10 +177,15 @@ principal_curve <- function(
     }
 
     for (jj in seq_len(ncol(x))) {
+      # Smooth (lambda, x)
       yjj <- smoother_function(pcurve$lambda, x[,jj], ...)
+
+      # If requested, approximate the smoothed curve to reduce computational complexity
       if (approx_points > 0) {
-        yjj <- approx(x = sort_lambda, y = yjj, xout = xout_lambda)$y
+        yjj <- stats::approx(x = sort_lambda, y = yjj, xout = xout_lambda, ties = "ordered")$y
       }
+
+      # Store curve
       s[,jj] <- yjj
     }
 
@@ -232,11 +236,7 @@ formals(principal_curve)$smoother <- names(smoother_functions)
 #' @export
 #' @importFrom graphics lines
 lines.principal_curve <- function(x, ...) {
-  if ("ord" %in% names(x)) {
-    ord <- x[["ord"]]
-  } else {
-    ord <- x[["tag"]]
-  }
+  ord <- x[["ord"]]
   graphics::lines(x$s[ord, ], ...)
 }
 
@@ -244,11 +244,7 @@ lines.principal_curve <- function(x, ...) {
 #' @export
 #' @importFrom graphics plot
 plot.principal_curve <- function(x, ...) {
-  if ("ord" %in% names(x)) {
-    ord <- x[["ord"]]
-  } else {
-    ord <- x[["tag"]]
-  }
+  ord <- x[["ord"]]
   graphics::plot(x$s[ord, ], ..., type = "l")
 }
 
